Module graph

Module graph 

Graph module

License

This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.

Code examples both in the docstrings and rendered documentation are free to use.

Re-exports

pub use crate::Edge;
pub use crate::EdgeStore;
pub use crate::EdgeStoreData;
pub use crate::HasEdgeStore;
pub use crate::HasNodeStore;
pub use crate::Meta;
pub use crate::Metadata;
pub use crate::Node;
pub use crate::NodeStore;
pub use crate::NodeStoreData;

Structs

Graph
A graph containing nodes and edges.

Enums

Error
Graph error.