Module node

Module node 

Node module

License

This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.

Code examples both in the docstrings and rendered documentation are free to use.

Structs

AscendantIterator
DescendantIterator
Node
A node in a graph.
NodeStoreData

Enums

NodeStoreError
Node error.

Traits

HasNodeStore
NodeStore